#include <LiquidCrystal_I2C.h>
#include <Servo.h>

#define unpress_angle 70 
#define press_angle 45
#define threshold 435
#define servoPin 9

/* Setup for LCD screen */
LiquidCrystal_I2C lcd(0x27,16,2);
/* Initialize servomotor */
Servo servo;

const int buttonPin = 2;
int buttonState = 0; 
bool playing = false;

/* Variable used for detecting button interrupt */
volatile bool buttonPressed = false;

ISR(PCINT2_vect) {
  if (!(PIND & (1 << PIND2))) {
    buttonPressed = true;
  }
}

void setup() {
  /* Initialize LCD screen */
  lcd.init();
  /* Clear content on the screen */
  lcd.clear();         
  /* Turn on backlight */
  lcd.backlight();

  /* Game hasn't started yet */
  playing = false;
  buttonPressed = false;
  
  /* Setup initial message on lcd */
  lcd.setCursor(2,0);
  lcd.print("Press the red");
  lcd.setCursor(0,1);
  lcd.print("button to start!");

  /* Setup Serial Monitor */
  Serial.begin(9600);

  /* Attach the servomotor to the object */
  servo.attach(servoPin);
  /* Set the servomotor position to the unpressed angle value */
  servo.write(unpress_angle);

  DDRD &= ~(1 << DDD2);
  PORTD |= (1 << PORTD2);

  PCMSK2 |= (1 << PCINT18);
  PCICR |= (1 << PCIE2);

  /* Enable interrupts */
  sei();
}

void loop() {
  /* Print fotoresistor's value */
  Serial.println(analogRead(A0));
  Serial.println("\n");

  /* Check if the pushbutton is pressed. If it is, set the game 
  as 'Playing' on the LCD screen*/                                                                                                                          
  if (buttonPressed && !playing) {
    playing = true;
    buttonPressed = false;

    /* Start the game */
    servo.write(press_angle);
    delay(100);

    /* Clear LCD and show text */
    lcd.clear();
    lcd.setCursor(2,0);
    lcd.print("Playing.. ");
  }

  /* If the game has started */
  if (playing == true) {   
    servo.write(unpress_angle);
    delay(10);
    if(analogRead(A0)< threshold)
    {
       servo.write(press_angle);
       /* Waits 100ms for the servo to reach the position */
       delay(100);                   
    }
  }                     
}
